@@ -3,9 +3,10 @@ mod node;
 pub use node::{BoxDynNode, IEnumTyped, INodeTrait, INodeType};
 // element trait
 mod element;
-pub use element::{
-	BoxDynElement, IAttrValue, IElementTrait, IFormValue, InsertPosition, MaybeElement,
-};
+pub use element::{BoxDynElement, IAttrValue, IElementTrait, IFormValue, MaybeElement};
+cfg_feat_insertion! {
+	pub use element::InsertPosition;
+}
 // text trait
 mod text;
 pub use text::{BoxDynText, ITextTrait};
@@ -16,8 +17,10 @@ pub use document::{IDocumentTrait, IErrorHandle, MaybeDoc};
 mod uncare;
 pub use uncare::{BoxDynUncareNode, IUncareNodeTrait};
 // texts
-mod texts;
-pub use texts::Texts;
+cfg_feat_text! {
+	mod texts;
+	pub use texts::Texts;
+}
 // elements
 mod elements;
 pub use elements::Elements;
